Package: Sofi
Type: Package
Language: es
Title: Interfaz interactiva con fines didacticos
Version: 0.16.4.8
Date: 2016-04-08
Depends: R (>= 3.1.0), shiny
Imports: sampling, foreign
Suggests: ggplot2, VGAM, shinyjs, ggExtra, grid, gridExtra
Encoding: UTF-8
Author: Jose D. Loera
Maintainer: Jose D. Loera <jose.loera@inegi.org.mx>
URL: http://www.sofi.uno/
NeedsCompilation: no
BugReports: https://github.com/loerasg/Sofi/issues
Description: Este paquete tiene la finalidad de ayudar a aprender de una forma interactiva, teniendo ejemplos y la posibilidad de resolver nuevos al mismo tiempo. Apuntes de clase interactivos.
License: GPL (>= 2)
Packaged: 2016-04-08 17:43:24 UTC; JOSE.LOERA
Repository: CRAN
Date/Publication: 2016-04-10 00:49:47
Built: R 4.6.0; ; 2026-04-28 21:30:21 UTC; unix
