---
title: "INEGI Defunciones"
author: "Jose D. Loera"
date: "1 de Agosto de 2015"
output: word_document
---

Esta es solo una prueba

This is an R Markdown document. Markdown is a simple formatting syntax for authoring HTML, PDF, and MS Word documents. For more details on using R Markdown see <http://rmarkdown.rstudio.com>.

When you click the **Knit** button a document will be generated that includes both content as well as the output of any embedded R code chunks within the document. You can embed an R code chunk like this:

```{r}
summary(cars)
```

You can also embed plots, for example: $A = \pi*r^{2}$ 

$$\frac { \sqrt { { \Re  }^{ \log { 2 }  } }  }{ \bigcap _{ x }^{ \infty  }{ \max _{ n=2 }{ { T }_{ n } }  }  } $$

```{r, echo=FALSE}
plot(cars)
```

Note that the `echo = FALSE` parameter was added to the code chunk to prevent printing of the R code that generated the plot.
